somspa creates a Self-Organizing Map from spatial data.
somspa(x, ...)A sominp object.
Other arguments passed to methods from kohonen::som function which is used to create the SOM.
A somsp object, which contains:
A summary data.table with the coordinates of each SOM node, the distances of objects
to their corresponding winning unit, the number of points of each node, as well as the median
latitude and longitude of each node coordinates and their standard deviation.
A Self-Organizing Map object (see also kohonen).
The sominp object used as input for the SOM, with an id number coressponding to
location and a node number to the classification group of SOM.
x should be created by sominp.
The output somsp objects can be plotted by plot and plot_ts functions or summarized by summary